# Copyright 2026 Ruihang Li.
# Licensed under the Apache License, Version 2.0.
# See LICENSE file in the project root for details.

"""Entry point for python -m genarena."""

from genarena.cli import main

if __name__ == "__main__":
    main()
